Data stores
Data stores are part of the catalog in Qlik Cloud. A data store may contain one or more data stores, which in turn may contain multiple data sets.
Endpoints
Facts
| Rate limit | Tier 1 (1000 requests per minute) |
Query Parameters
- limit integer
Page size limit.
- page integer
- projections array of strings
Comma-separated fields to return in the response.
- sort array of strings
Comma-separated fields and field start with '-' character sorts the result set in descending order.
Responses
200
Successful Operation
- application/json object
application/json properties
- data array of objects
data properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
- page integer
- limit integer
- links object
links properties
- last object
last properties
- href string
-
- next object
next properties
- href string
-
- prev object
prev properties
- href string
-
- self object
self properties
- href string
-
- first object
first properties
- href string
-
-
- pages integer
- total integer
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.getDataStores({})qlik data-store lscurl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores" \-H "Authorization: Bearer <access_token>"Example Response
{ "data": [ { "id": "string", "uri": "string", "name": "string", "tags": [ "string" ], "type": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string" } ], "page": 42, "limit": 42, "links": { "last": { "href": "string" }, "next": { "href": "string" }, "prev": { "href": "string" }, "self": { "href": "string" }, "first": { "href": "string" } }, "pages": 42, "total": 42}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Request Body
Required- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- description string
- technicalName stringRequired
- technicalDescription string
-
Responses
201
Created new data store successfully.
- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.createDataStore({ description: 'string', id: 'string', name: 'string', ownerId: 'string', properties: {}, spaceId: 'string', tags: ['string'], technicalDescription: 'string', technicalName: 'string', type: 'string', uri: 'string', version: 42,})qlik data-store create \ --technicalName 'string' \ --type 'string'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores" \-X POST \-H "Content-type: application/json" \-H "Authorization: Bearer <access_token>" \-d '{"id":"string","uri":"string","name":"string","tags":["string"],"type":"string","ownerId":"string","spaceId":"string","version":42,"properties":{},"description":"string","technicalName":"string","technicalDescription":"string"}'Example Response
{ "id": "string", "uri": "string", "name": "string", "tags": [ "string" ], "type": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string"}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Request Body
Required- application/json object
application/json properties
- ids array of strings
-
Responses
204
Deleted empty data stores.
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.deleteDataStores({ ids: ['string'],})qlik data-store delete-manycurl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores" \-X DELETE \-H "Content-type: application/json" \-H "Authorization: Bearer <access_token>" \-d '{"ids":["string"]}'Facts
| Rate limit | Tier 1 (1000 requests per minute) |
Query Parameters
- projections array of strings
Comma-separated fields to return in the response.
Path Parameters
- data-store-id stringRequired
Responses
200
Successful Operation.
- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.getDataStore('string', {})qlik data-store get 'string'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-id}" \-H "Authorization: Bearer <access_token>"Example Response
{ "id": "string", "uri": "string", "name": "string", "tags": [ "string" ], "type": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string"}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Path Parameters
- data-store-id stringRequired
Request Body
Required- application/json array of objects
Array of JSON patch documents as defined by RFC 6902.
application/json properties
- op stringRequired
The operation to be performed.
Can be one of: "add""remove""replace""move""copy""test"
- from string
A JSON Pointer path pointing to the location to move/copy from.
- path stringRequired
A JSON pointer to the property being affected.
- value object
The value to add, replace or test.
-
Responses
200
Patched data store successfully.
- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
204
Patched data store successfully.
- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.patchDataStore('string', [ { from: 'string', op: 'add', path: 'string', value: {}, },])qlik data-store patch 'string' \ --op 'add' \ --path 'string'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-id}" \-X PATCH \-H "Content-type: application/json" \-H "Authorization: Bearer <access_token>" \-d '[{"op":"add","from":"string","path":"string","value":{}}]'Example Response
{ "id": "string", "uri": "string", "name": "string", "tags": [ "string" ], "type": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string"}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Path Parameters
- data-store-id stringRequired
Request Body
Required- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- description string
- technicalName stringRequired
- technicalDescription string
-
Responses
200
Updated data store successfully.
- application/json object
application/json properties
- id string
Only required when updating the resource. Must be null for new resources.
- uri string
- name string
- tags array of strings
- type stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.updateDataStore('string', { description: 'string', id: 'string', name: 'string', ownerId: 'string', properties: {}, spaceId: 'string', tags: ['string'], technicalDescription: 'string', technicalName: 'string', type: 'string', uri: 'string', version: 42,})qlik data-store update 'string' \ --technicalName 'string' \ --type 'string'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-id}" \-X PUT \-H "Content-type: application/json" \-H "Authorization: Bearer <access_token>" \-d '{"id":"string","uri":"string","name":"string","tags":["string"],"type":"string","ownerId":"string","spaceId":"string","version":42,"properties":{},"description":"string","technicalName":"string","technicalDescription":"string"}'Example Response
{ "id": "string", "uri": "string", "name": "string", "tags": [ "string" ], "type": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string"}Facts
| Rate limit | Tier 1 (1000 requests per minute) |
Query Parameters
- limit integer
Page size limit.
- page integer
- projections array of strings
Comma-separated fields to return in the response.
- sort array of strings
Comma-separated fields and field start with '-' character sorts the result set in descending order.
Path Parameters
- data-store-ids array of stringsRequired
Comma-separated data store IDs or * to include all data stores.
Responses
200
Successful Operation
- application/json object
application/json properties
- data array of objects
data properties
- id string
Only required when updating the resource. Must be null for new resources.
- name string
- tags array of strings
- appId string
- appType stringRequired
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- dataFreshness string
The date-time when the source data was last changed
- dataStoreInfo object
dataStoreInfo properties
- id stringRequired
- name string
- type string
-
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- technicalDescription string
-
- page integer
- limit integer
- links object
links properties
- last object
last properties
- href string
-
- next object
next properties
- href string
-
- prev object
prev properties
- href string
-
- self object
self properties
- href string
-
- first object
first properties
- href string
-
-
- pages integer
- total integer
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.getDataStoreDataAssets( 'value', {},)qlik data-store data-asset ls 'value'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-ids}/data-assets" \-H "Authorization: Bearer <access_token>"Example Response
{ "data": [ { "id": "string", "name": "string", "tags": [ "string" ], "appId": "string", "appType": "string", "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "dataFreshness": "2018-10-30T07:06:22Z", "dataStoreInfo": { "id": "string", "name": "string", "type": "string" }, "technicalName": "string", "lastModifiedBy": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "technicalDescription": "string" } ], "page": 42, "limit": 42, "links": { "last": { "href": "string" }, "next": { "href": "string" }, "prev": { "href": "string" }, "self": { "href": "string" }, "first": { "href": "string" } }, "pages": 42, "total": 42}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Path Parameters
- data-store-ids array of stringsRequired
Comma-separated data store IDs or * to include all data stores.
Responses
204
Deleted data assets successfully.
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.deleteDataStoreDataAssets( 'value',)qlik data-store data-asset delete-many 'value'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-ids}/data-assets" \-X DELETE \-H "Authorization: Bearer <access_token>"Facts
| Rate limit | Tier 1 (1000 requests per minute) |
Query Parameters
- limit integer
Page size limit.
- page integer
- projections array of strings
Comma-separated fields to return in the response.
- sort array of strings
Comma-separated fields and field start with '-' character sorts the result set in descending order.
Path Parameters
- data-asset-ids array of stringsRequired
Comma-separated data asset IDs or * to include all data assets.
- data-store-ids array of stringsRequired
Comma-separated data store IDs or * to include all data stores.
Responses
200
Successful Operation.
- application/json object
application/json properties
- data array of objects
data properties
- id string
Only required when updating the resource. Must be null for new resources.
- qri stringRequired
NOTE: this will be deprecated after migration to secureQri. Required user defined field. All the parts in the format must be separated by ':'. The first part denotes the resourceType, followed by dataStoreType and tenant guid. The spaceGuid or userGuid is to be populated based on if the dataset is in shared or private space and finally the full file name. This field is auto populated for the dataSet generated for qix-datafiles.
- name string
- tags array of strings
- type string
- schema object
Optional field to specify additional schemas for files where multiple tables or sheets are available. User must define primary schema in 'schema' attribute and rest of the sheets/ tables can be defined using this field. This field is not populated for the dataSets with single schema
schema properties
- anomalies array of strings
Anomalies associated with this schema. Example: $warning-unknown-headers
- dataFields array of objectsRequired
dataFields properties
- name stringRequired
- tags array of strings
An array of system tags
- alias string
Alias of the field. Must be unique within the schema and must not match another field's name. Returns
400if violated. - index integer
- orphan boolean
- dataType objectRequired
dataType properties
- type stringRequired
Each datatype may vary in terms of required properties. Example: Datatype DECIMAL requires two mandatory properties to be defined - precision and scale, each one accepts integer value. All other datatypes does not have any required properties.
Can be one of: "DATE""TIME""DATETIME""TIMESTAMP""STRING""DOUBLE""DECIMAL""INTEGER""BOOLEAN""BINARY""CUSTOM"
- properties object
The properties map key is string and the value is of type object. Please note, Datatype DECIMAL requires two mandatory properties to be defined; these properties must be named: precision and scale, each of these property accepts integer value. All other datatypes does not require any manadatory properties to be defined.
additional optional properties
- object object
The properties map key is string and the value is of type object. Please note, Datatype DECIMAL requires two mandatory properties to be defined; these properties must be named: precision and scale, each of these property accepts integer value. All other datatypes does not require any manadatory properties to be defined.
-
- originalType string
-
- nullable boolean
- userTags array of objects
An array of user-supplied tags
userTags properties
- id string
The id of the tag in Collections
- name string
-
- encrypted boolean
- sensitive boolean
- primaryKey boolean
- properties object
additional optional properties
- object object
-
- description string
- ordinalPositionInKey integer
-
- schemaName string
- loadOptions object
Options for loading files. Example: "qLabel": "embedded labels"
additional optional properties
- object object
Options for loading files. Example: "qLabel": "embedded labels"
-
- effectiveDate string
- overrideSchemaAnomalies boolean
-
- ownerId string
The value is automatically set by the application.
- spaceId string
- version integer
Only required when updating the resource. Must be null for new resources.
- tenantId string
The value is automatically set by the application. User defined value is ignored.
- createdBy string
The value is automatically set by the application. User defined value is ignored.
- secureQri stringRequired
- properties object
A Map of name-value pairs.
additional optional properties
- object object
A Map of name-value pairs.
-
- createdTime string
The value is automatically set by the application. User defined value is ignored.
- description string
- operational object
operational properties
- size integer
- status string
- endDate string
- location string
- rowCount integer
- startDate string
- logMessage string
- tableOwner string
- lastLoadTime string
- contentUpdated boolean
- lastUpdateTime string
- tableConnectionInfo object
tableConnectionInfo properties
- tableName string
- selectionScript string
- additionalProperties object
additional optional properties
- string string
-
-
-
- dataAssetInfo objectRequired
dataAssetInfo properties
- id stringRequired
- name string
- dataStoreInfo object
dataStoreInfo properties
- id stringRequired
- name string
- type string
-
-
- technicalName stringRequired
- lastModifiedBy string
The value is automatically set by the application. User defined value is ignored.
- appTypeOverride string
Optional override of DataAsset appType.
- lastModifiedTime string
The value is automatically set by the application. User defined value is ignored.
- additionalSchemas array of objects
Optional field to specify additional schemas for files where multiple tables or sheets are available. User must define primary schema in 'schema' attribute and rest of the sheets/ tables can be defined using this field. This field is not populated for the dataSets with single schema
additionalSchemas properties
- anomalies array of strings
Anomalies associated with this schema. Example: $warning-unknown-headers
- dataFields array of objectsRequired
dataFields properties
- name stringRequired
- tags array of strings
An array of system tags
- alias string
Alias of the field. Must be unique within the schema and must not match another field's name. Returns
400if violated. - index integer
- orphan boolean
- dataType objectRequired
dataType properties
- type stringRequired
Each datatype may vary in terms of required properties. Example: Datatype DECIMAL requires two mandatory properties to be defined - precision and scale, each one accepts integer value. All other datatypes does not have any required properties.
Can be one of: "DATE""TIME""DATETIME""TIMESTAMP""STRING""DOUBLE""DECIMAL""INTEGER""BOOLEAN""BINARY""CUSTOM"
- properties object
The properties map key is string and the value is of type object. Please note, Datatype DECIMAL requires two mandatory properties to be defined; these properties must be named: precision and scale, each of these property accepts integer value. All other datatypes does not require any manadatory properties to be defined.
additional optional properties
- object object
The properties map key is string and the value is of type object. Please note, Datatype DECIMAL requires two mandatory properties to be defined; these properties must be named: precision and scale, each of these property accepts integer value. All other datatypes does not require any manadatory properties to be defined.
-
- originalType string
-
- nullable boolean
- userTags array of objects
An array of user-supplied tags
userTags properties
- id string
The id of the tag in Collections
- name string
-
- encrypted boolean
- sensitive boolean
- primaryKey boolean
- properties object
additional optional properties
- object object
-
- description string
- ordinalPositionInKey integer
-
- schemaName string
- loadOptions object
Options for loading files. Example: "qLabel": "embedded labels"
additional optional properties
- object object
Options for loading files. Example: "qLabel": "embedded labels"
-
- effectiveDate string
- overrideSchemaAnomalies boolean
-
- technicalDescription string
- createdByConnectionId string
The connectionId that created the Dataset. Optional.
-
- page integer
- limit integer
- links object
links properties
- last object
last properties
- href string
-
- next object
next properties
- href string
-
- prev object
prev properties
- href string
-
- self object
self properties
- href string
-
- first object
first properties
- href string
-
-
- pages integer
- total integer
-
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.getDataStoreDataAssetDataSets( 'value', 'value', {},)qlik data-store data-asset data-set ls \ --data-store-ids 'value' \ --data-asset-ids 'value'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-ids}/data-assets/{data-asset-ids}/data-sets" \-H "Authorization: Bearer <access_token>"Example Response
{ "data": [ { "id": "string", "qri": "string", "name": "string", "tags": [ "string" ], "type": "string", "schema": { "anomalies": [ "string" ], "dataFields": [ { "name": "string", "tags": [ "string" ], "alias": "string", "index": 42, "orphan": true, "dataType": { "type": "DATE", "properties": {}, "originalType": "string" }, "nullable": true, "userTags": [ { "id": "string", "name": "string" } ], "encrypted": true, "sensitive": true, "primaryKey": true, "properties": {}, "description": "string", "ordinalPositionInKey": 42 } ], "schemaName": "string", "loadOptions": {}, "effectiveDate": "2018-10-30T07:06:22Z", "overrideSchemaAnomalies": true }, "ownerId": "string", "spaceId": "string", "version": 42, "tenantId": "string", "createdBy": "string", "secureQri": "string", "properties": {}, "createdTime": "2018-10-30T07:06:22Z", "description": "string", "operational": { "size": 42, "status": "string", "endDate": "2018-10-30T07:06:22Z", "location": "string", "rowCount": 42, "startDate": "2018-10-30T07:06:22Z", "logMessage": "string", "tableOwner": "string", "lastLoadTime": "2018-10-30T07:06:22Z", "contentUpdated": true, "lastUpdateTime": "2018-10-30T07:06:22Z", "tableConnectionInfo": { "tableName": "string", "selectionScript": "string", "additionalProperties": {} } }, "dataAssetInfo": { "id": "string", "name": "string", "dataStoreInfo": { "id": "string", "name": "string", "type": "string" } }, "technicalName": "string", "lastModifiedBy": "string", "appTypeOverride": "string", "lastModifiedTime": "2018-10-30T07:06:22Z", "additionalSchemas": [ { "anomalies": [ "string" ], "dataFields": [ { "name": "string", "tags": [ "string" ], "alias": "string", "index": 42, "orphan": true, "dataType": { "type": "DATE", "properties": {}, "originalType": "string" }, "nullable": true, "userTags": [ { "id": "string", "name": "string" } ], "encrypted": true, "sensitive": true, "primaryKey": true, "properties": {}, "description": "string", "ordinalPositionInKey": 42 } ], "schemaName": "string", "loadOptions": {}, "effectiveDate": "2018-10-30T07:06:22Z", "overrideSchemaAnomalies": true } ], "technicalDescription": "string", "createdByConnectionId": "string" } ], "page": 42, "limit": 42, "links": { "last": { "href": "string" }, "next": { "href": "string" }, "prev": { "href": "string" }, "self": { "href": "string" }, "first": { "href": "string" } }, "pages": 42, "total": 42}Facts
| Rate limit | Tier 2 (100 requests per minute) |
Path Parameters
- data-asset-ids array of stringsRequired
Comma-separated data asset IDs or * to include all data assets.
- data-store-ids array of stringsRequired
Comma-separated data store IDs or * to include all data stores.
Responses
204
Deleted data sets.
400
The request is in incorrect format.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
401
User does not have valid authentication credentials.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
403
User does not have access to the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
404
Resource does not exist.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
409
The input request conflicts with the current state of the resource.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
500
Internal Server Error.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
503
Requested service is not available.
- application/json object
application/json properties
- errors array of objects
errors properties
- code string
- meta object
Optional free-form metadata associated with the error.
- title string
- detail string
- status string
-
- traceId string
-
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({ hostConfig: { host: 'https://{tenant}.{region}.qlikcloud.com', apiKey: '<access-token>', },})
await qlik.dataStores.deleteDataStoreDataAssetDataSets( 'value', 'value',)qlik data-store data-asset data-set delete-many \ --data-store-ids 'value' \ --data-asset-ids 'value'curl "https://{tenant}.{region}.qlikcloud.com/api/v1/data-stores/{data-store-ids}/data-assets/{data-asset-ids}/data-sets" \-X DELETE \-H "Authorization: Bearer <access_token>"